Class: Dcc::V3::Quantity

Inherits:
CommonElements show all
Defined in:
lib/dcc/v3/quantity.rb

Overview

V3 Quantity: declares DCC admin attributes + D-SI v2.x quantity element references in a single xml do block. We avoid include Dcc::Base::Quantity because the second xml do block would overwrite the base mappings.

Method Summary

Methods inherited from CommonElements

lutaml_default_register

Methods inherited from CommonElements

lutaml_default_register