Module: Dcc::Base::Comment
- Included in:
- V2::Comment, V3::Comment
- Defined in:
- lib/dcc/base/comment.rb
Overview
dcc:comment — wildcard (xs:any namespace="##any") wrapper around
arbitrary XML. The contents are preserved as a raw XML string; lutaml-model
requires map_all to be the only mapping in a class, so the comment
element lives in its own class referenced by DigitalCalibrationCertificate.